Initializing...

# Setup Gitpages

For this step you need to do three things:

- Create a github account (if you don't have one yet)
- Install Git on your system
- Create a new repository named exactly '(your username).github.io'
- Clone the repository locally

You can do this yourself, the gitpages documentation is pretty good

If you succeed in doing this manually, you can close this window and continue with the installer setup. Otherwise, you can continue below. Make sure that you have at least a github account before you continue below.

## Configure Repo

Github username:

## Check prequisites

In this step we will test if Git is installed and whether it is configured correctly.

### Install Git

Git was not found on your system. Follow one of the following links to install Git on your system.

- Linux: https://git-scm.com/download/linux
- macOS: https://git-scm.com/download/mac
- Windows: https://gitforwindows.org/
  (When in doubt: pick Git Bash and install with default settings.)

Run check again after a successful installation.

### Set git user.name

No username setting was found in your global settings.

This installer will work with local settings, but in that case you must skip this sub-installer and do the git repo creation and git clone steps manually.
Github user.name:

Run check again after a successful set.

### Set git user.email

No username setting was found in your global settings.

This installer will work with local settings, but in that case you must skip this sub-installer and do the git repo creation and git clone steps manually.
Github user.email:

Run check again after a successful set.

## Choose where to clone your repo to

## Clone

This step will clone the configured repo to the configured local folder.

Please first run the pre-clone check to guarantee that all the values are populated correctly in the backend.

## Done setting up git pages

All local settings are ready to start publishing to your own gitpage. We haven't created the website yet, but we can continue in the main installation wizard with getting you set up for that.

Close this window and continue in the main installer to complete setting up gitpage publishing.